@@ -12,6 +12,7 @@
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD and Duncan)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
+#' @param names.fat Name of factors
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param grau Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with two elements.
@@ -91,6 +92,7 @@ FAT2DIC.ad=function(f1,
                     alpha.f=0.05,
                     alpha.t=0.05,
                     quali=c(TRUE,TRUE),
+                    names.fat=c("F1","F2"),
                     mcomp="tukey",
                     grau=c(NA,NA),
                     grau12=NA, # F1/F2
@@ -167,7 +169,6 @@ FAT2DIC.ad=function(f1,
   nv2 <- length(summary(Fator2))
   lf1 <- levels(Fator1)
   lf2 <- levels(Fator2)
-  fac.names = c("F1", "F2")
   fatores <- cbind(fator1, fator2)
   J = length(respAd)
   n.trat2 <- nv1 * nv2
@@ -292,6 +293,8 @@ FAT2DIC.ad=function(f1,
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
+  rownames(anava1)=c(names.fat[1],names.fat[2],
+                     paste(names.fat[1],"x",names.fat[2]),"Ad x Factorial","Residuals")
   print(anava1,na.print = "")
   cat("\n")
   if(anava$`Pr(>F)`[4]<alpha.f){"The additional treatment does differ from the factorial by the F test"}else{"The additional treatment does not differ from the factorial by the F test "}
@@ -311,7 +314,7 @@ FAT2DIC.ad=function(f1,
 
     for (i in 1:2) {if (anava$`Pr(>F)`[i] <= alpha.f)
     {cat(green(bold("\n-----------------------------------------------------------------\n")))
-      cat(bold(fac.names[i]))
+      cat(bold(names.fat[i]))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       if(quali[i]==TRUE){
         ## Tukey
@@ -438,7 +441,7 @@ FAT2DIC.ad=function(f1,
                            theme=theme,
                            textsize=textsize,
                            point=point,
-                           family=family)
+                           family=family,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])
         grafico=grafico[[1]]+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
@@ -490,6 +493,19 @@ FAT2DIC.ad=function(f1,
     des1.tab=des1.tab[-c(nlinhas),]
     des1.tab$`F value`=des1.tab$`Mean Sq`/anava$`Mean Sq`[5]
     des1.tab$`Pr(>F)`=1-pf(des1.tab$`F value`,des1.tab$Df,anava$Df[5])
+
+    cat("\n-----------------------------------------------------------------\n")
+    cat("Analyzing ", names.fat[1], " inside of the level of ",names.fat[2])
+    cat("\n-----------------------------------------------------------------\n")
+    cat("\n")
+    rn<-numeric(0)
+    for (j in 1:nv2) {
+      rn <- c(rn, paste(paste(names.fat[1], ":", names.fat[2],
+                              sep = ""), lf2[j]))
+    }
+    rownames(des1.tab)=c(names.fat[2],
+                         paste(names.fat[1],"x",names.fat[2],"+",names.fat[1]),
+                         paste("  ",rn))
     print(des1.tab)
     desdobramento1=des1.tab
     if(quali[1]==TRUE & quali[2]==TRUE){
@@ -559,7 +575,7 @@ FAT2DIC.ad=function(f1,
                         QME = anava$`Mean Sq`[5],
                         alpha = alpha.t)
           sk=data.frame(respi=medias,groups=sk)
-          if(transf !="1"){sk$groups$respo=tapply(respi,trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
+          if(transf !="1"){sk$groups$respo=tapply(respi,trati,mean, na.rm=TRUE)[rownames(sk)]}
           skgrafico[[i]]=sk[levels(trati),2]
           ordem[[i]]=rownames(sk[levels(trati),])
         }
@@ -571,7 +587,7 @@ FAT2DIC.ad=function(f1,
     }
 
     cat("\n-----------------------------------------------------------------\n")
-    cat("Analyzing ", fac.names[2], " inside of the level of ",fac.names[1])
+    cat("Analyzing ", names.fat[2], " inside of the level of ",names.fat[1])
     cat("\n-----------------------------------------------------------------\n")
     cat("\n")
     des1<-aov(resp~Fator1/Fator2)
@@ -589,6 +605,15 @@ FAT2DIC.ad=function(f1,
     des1.tab=des1.tab[-c(nlinhas),]
     des1.tab$`F value`=des1.tab$`Mean Sq`/anava$`Mean Sq`[5]
     des1.tab$`Pr(>F)`=1-pf(des1.tab$`F value`,des1.tab$Df,anava$Df[5])
+
+    rn<-numeric(0)
+    for (i in 1:nv1) {
+      rn <- c(rn, paste(paste(names.fat[2], ":", names.fat[1],
+                              sep = ""), lf1[i]))
+    }
+    rownames(des1.tab)=c(names.fat[1],
+                         paste(names.fat[1],"x",names.fat[2],"+",names.fat[2]),
+                         paste("  ",rn))
     print(des1.tab)
     desdobramento2=des1.tab
 
@@ -658,7 +683,7 @@ FAT2DIC.ad=function(f1,
                             point=point,
                             textsize=textsize,
                             family=family,
-                            ylim=ylim)+
+                            ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
       if(quali[2]==TRUE){
@@ -674,7 +699,7 @@ FAT2DIC.ad=function(f1,
                             point=point,
                             textsize=textsize,
                             family=family,
-                            ylim=ylim)+
+                            ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
     }
@@ -692,7 +717,7 @@ FAT2DIC.ad=function(f1,
                                   point=point,
                                   textsize=textsize,
                                   family=family,
-                                  ylim=ylim)+
+                                  ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
       if(quali[2]==TRUE){
@@ -708,7 +733,7 @@ FAT2DIC.ad=function(f1,
                                   point=point,
                                   textsize=textsize,
                                   family=family,
-                                  ylim=ylim)+
+                                  ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
     }
