@@ -13,6 +13,7 @@
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
 #' @param grau Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with three elements.
+#' @param names.fat Name of factors
 #' @param grau12 Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with n levels of factor 2, in the case of interaction f1 x f2 and qualitative factor 2 and quantitative factor 1.
 #' @param grau21 Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with n levels of factor 1, in the case of interaction f1 x f2 and qualitative factor 1 and quantitative factor 2.
 #' @param geom Graph type (columns or segments (For simple effect only))
@@ -82,6 +83,7 @@ PSUBDBC=function(f1,
                  alpha.f=0.05,
                  alpha.t=0.05,
                  quali=c(TRUE,TRUE),
+                 names.fat=c("F1","F2"),
                  mcomp = "tukey",
                  grau=c(NA,NA),
                  grau12=NA, # F1/F2
@@ -270,6 +272,8 @@ PSUBDBC=function(f1,
   cat(green(bold("Analysis of Variance")))
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   anova$`Pr(>F)`=ifelse(anova$`Pr(>F)`>0.001,round(anova$`Pr(>F)`,3),"p<0.001")
+  rownames(anova)=c(names.fat[1],"Block","Error A",names.fat[2],
+                     paste(names.fat[1],":",names.fat[2]),"Error B")
   print(as.matrix(anova),na.print="",quote = FALSE)
 
   if(transf==1 && norm1$p.value<0.05 |  transf==1 &&homog1$p.value<0.05){
@@ -474,7 +478,7 @@ PSUBDBC=function(f1,
     cat(green(bold("-----------------------------------------------------------------\n")))
     cat("Significant interaction: analyzing the interaction")
     cat(green(bold("\n-----------------------------------------------------------------\n")))
-    cat(green(bold("Analyzing ", fac[1], " inside of each level of ", fac[2])))
+    cat(green(bold("Analyzing ", names.fat[1], " inside of each level of ", names.fat[2])))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     l2 <- names(summary(Fator2))
     sq <- numeric(0)
@@ -502,6 +506,12 @@ PSUBDBC=function(f1,
     tab.f1f2 <- round(tab.f1f2, 6)
     tab.f1f2[nv2 + 1, 2] <- tab.f1f2[nv2 + 1, 3] * tab.f1f2[nv2 + 1, 1]
     tab.f1f2[nv2 + 1, 5] <- tab.f1f2[nv2 + 1, 4] <- ""
+    rn<-numeric(0)
+    for (j in 1:nv2) {
+      rn <- c(rn, paste(paste(names.fat[1], ":", names.fat[2],
+                              sep = ""), lf2[j]))
+    }
+    rownames(tab.f1f2)=c(rn,"Combined error")
     print(tab.f1f2)
     desdobramento1=tab.f1f2
     #-------------------------------------
@@ -576,7 +586,7 @@ PSUBDBC=function(f1,
           #              num(tab.f1f2[nv2+1,1]),
           #              num(tab.f1f2[nv2+1,2]),alpha.t)
           if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
-                                           trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
+                                           trati,mean, na.rm=TRUE)[rownames(sk)]}
           skgrafico[[i]]=sk[levels(trati),2]
           ordem[[i]]=rownames(sk[levels(trati),])
         }
@@ -592,7 +602,7 @@ PSUBDBC=function(f1,
     # Desdobramento de F2 dentro de F1
     #-------------------------------------
     cat(green(bold("\n-----------------------------------------------------------------\n")))
-    cat(green(bold("Analyzing ", fac[2], " inside of the level of ",fac[1])))
+    cat(green(bold("Analyzing ", names.fat[2], " inside of the level of ",names.fat[1])))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     l1 <- names(summary(Fator1))
     sq <- numeric(0)
@@ -616,6 +626,12 @@ PSUBDBC=function(f1,
     rownames(tab.f2f1) <- nome.f2f1
     tab.f2f1 <- round(tab.f2f1, 6)
     tab.f2f1[nv1 + 1, 5] <- tab.f2f1[nv1 + 1, 4] <- ""
+    rn<-numeric(0)
+    for (i in 1:nv1) {
+      rn <- c(rn, paste(paste(names.fat[2], ":", names.fat[1],
+                              sep = ""), lf1[i]))
+    }
+    rownames(tab.f2f1)=c(rn,"Error b")
     print(tab.f2f1)
     desdobramento2=tab.f2f1
     #-------------------------------------
@@ -816,7 +832,7 @@ PSUBDBC=function(f1,
             #              num(tab.f1f2[nv2+1,1]),
             #              num(tab.f1f2[nv2+1,2]),alpha.t)
             if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
-                                             trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
+                                             trati,mean, na.rm=TRUE)[rownames(sk)]}
             cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
@@ -836,8 +852,8 @@ PSUBDBC=function(f1,
                             ylim=ylim,
                             textsize=textsize,
                             family=family,
-                            DFres = num(tab.f1f2[nv2+1,1]),
-                            SSq = num(tab.f1f2[nv2+1,2]))
+                            DFres = num(tab.f2f1[nv1+1,1]),
+                            SSq = num(tab.f2f1[nv1+1,2]))
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf=list(grafico,NA)}
       }
@@ -922,8 +938,8 @@ PSUBDBC=function(f1,
                             ylim=ylim,
                             textsize=textsize,
                             family=family,
-                            DFres = num(tab.f2f1[nv1 +1, 1]),
-                            SSq = num(tab.f2f1[nv1 + 1, 2]))
+                            DFres = num(tab.f1f2[nv2 +1, 1]),
+                            SSq = num(tab.f1f2[nv2 + 1, 2]))
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf[[2]]=grafico
           grafico=graf}
@@ -981,7 +997,7 @@ PSUBDBC=function(f1,
             #              num(tab.f1f2[nv2+1,1]),
             #              num(tab.f1f2[nv2+1,2]),alpha.t)
             if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
-                                             trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
+                                             trati,mean, na.rm=TRUE)[rownames(sk)]}
             cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
@@ -1001,8 +1017,8 @@ PSUBDBC=function(f1,
                                   ylim=ylim,
                                   textsize=textsize,
                                   family=family,
-                                  DFres = num(tab.f1f2[nv2+1,1]),
-                                  SSq = num(tab.f1f2[nv2+1,2]))
+                                  DFres = num(tab.f2f1[nv1+1,1]),
+                                  SSq = num(tab.f2f1[nv1+1,2]))
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf=list(grafico,NA)}
       }
@@ -1080,8 +1096,8 @@ PSUBDBC=function(f1,
                                   posi = posi,ylim=ylim,
                                   textsize=textsize,
                                   family=family,
-                                  DFres = num(tab.f2f1[nv1 +1, 1]),
-                                  SSq = num(tab.f2f1[nv1 + 1, 2]))
+                                  DFres = num(tab.f1f2[nv2 +1, 1]),
+                                  SSq = num(tab.f1f2[nv2 + 1, 2]))
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf[[2]]=grafico
           grafico=graf}
