@@ -7,6 +7,7 @@
 #' @param model DIC, DBC or DQL object
 #' @param fill fill bars
 #' @param horiz Horizontal Column (\emph{default} is TRUE)
+#' @param width.col Width Column
 #' @export
 #' @return Returns a bar chart for one factor
 #' @seealso \link{radargraph}, \link{barplot_positive}, \link{plot_TH}, \link{plot_TH1}, \link{corgraph}, \link{spider_graph}, \link{line_plot}, \link{plot_cor}, \link{plot_interaction}, \link{plot_jitter}, \link{seg_graph}, \link{TBARPLOT.reverse}
@@ -20,7 +21,8 @@
 
 bar_graph=function(model,
                    fill="lightblue",
-                   horiz=TRUE){
+                   horiz=TRUE,
+                   width.col=0.9){
   requireNamespace("ggplot2")
   data=model[[1]]$data
   media=data$media
@@ -35,16 +37,16 @@ bar_graph=function(model,
                           x=media))+
       model[[1]]$theme+
       geom_col(size=0.3,fill=fill,
-               color="black")+
+               color="black",width = width.col)+
       geom_errorbar(aes(xmin=media-desvio,
-                        xmax=media+desvio),width=0.2)+
+                        xmax=media+desvio),width=model[[1]]$plot$width.bar)+
       geom_text(aes(x=media+desvio+sup,
                      y=trats,
                      label = letra),hjust=0)+
       labs(y=model[[1]]$labels$x,
            x=model[[1]]$labels$y)+
-      theme(axis.text = element_text(size=12,color="black"),
-            strip.text = element_text(size=12),
+      theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+            strip.text = element_text(size=model[[1]]$plot$textsize),
             legend.position = "none")+
       scale_y_discrete(limits=trats)+
       xlim(layer_scales(model[[1]])$y$range$range*1.1)}
@@ -52,16 +54,16 @@ bar_graph=function(model,
     graph=ggplot(data,aes(x=trats,
                           y=media))+
       model[[1]]$theme+
-      geom_col(fill=fill,size=0.3,color="black")+
+      geom_col(fill=fill,size=0.3,color="black",width = width.col)+
       geom_errorbar(aes(ymin=media-desvio,
-                        ymax=media+desvio),width=0.2)+
+                        ymax=media+desvio),width=model[[1]]$plot$width.bar)+
       geom_text(aes(y=media+desvio+sup,
                      x=trats,
                      label = letra),vjust=0)+
       labs(x=model[[1]]$labels$x,
            y=model[[1]]$labels$y)+
-      theme(axis.text = element_text(size=12,color="black"),
-            strip.text = element_text(size=12),
+      theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+            strip.text = element_text(model[[1]]$plot$textsize),
             legend.position = "none")+
       scale_x_discrete(limits=trats)+
       ylim(layer_scales(model[[1]])$y$range$range*1.1)}
