@@ -224,6 +224,7 @@ DBC=function(trat,
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
+  rownames(anava1)=c("Treatment","Block","Residuals")
   print(anava1,na.print = "")
   cat("\n")
   message(if (a$`Pr(>F)`[1]<alpha.f){
@@ -394,15 +395,15 @@ DBC=function(trat,
       }
       vv<-as.numeric(v)
       junto <- data.frame(evaluation, trt)
-      medians<-mean.stat(junto[,1],junto[,2],stat="median")
+      medians<-mean_stat(junto[,1],junto[,2],stat="median")
       for(i in c(1,5,2:4)) {
-        x <- mean.stat(junto[,1],junto[,2],function(x)quantile(x)[i])
+        x <- mean_stat(junto[,1],junto[,2],function(x)quantile(x)[i])
         medians<-cbind(medians,x[,2])}
       medians<-medians[,3:7]
       names(medians)<-c("Min","Max","Q25","Q50","Q75")
-      Means <- mean.stat(junto[,1],junto[,2],stat="mean")
-      sds <-   mean.stat(junto[,1],junto[,2],stat="sd")
-      nn <-   mean.stat(junto[,1],junto[,2],stat="length")
+      Means <- mean_stat(junto[,1],junto[,2],stat="mean")
+      sds <-   mean_stat(junto[,1],junto[,2],stat="sd")
+      nn <-   mean_stat(junto[,1],junto[,2],stat="length")
       nr<-unique(nn[,2])
       s<-array(0,m[2])
       for (j in 1:m[2]){
